collect_interned_strings

Function collect_interned_strings 

pub fn collect_interned_strings<B>() -> B
where B: FromIterator<IStr>,
Create a collection of all the currently interned strings

The order of the items in the collection may not be stable.

let istrs: Vec<IStr> = collect_interned_strings();