pub fn collect_interned_strings<B>() -> Bwhere
B: FromIterator<IStr>,Expand description
Create a collection of all the currently interned strings
The order of the items in the collection may not be stable.
let istrs: Vec<IStr> = collect_interned_strings();